import * as i0 from '@angular/core';
import { Directive, Input, InjectionToken, NgModule } from '@angular/core';
import { OpenFeature, ClientProviderEvents, ClientProviderStatus } from '@openfeature/web-sdk';
export * from '@openfeature/web-sdk';
import { CommonModule } from '@angular/common';

class FeatureFlagDirectiveContext {
    constructor(details) {
        this.$implicit = details.value;
        this.evaluationDetails = details;
    }
}
class FeatureFlagDirective {
    constructor(_changeDetectorRef, _viewContainerRef, templateRef) {
        this._changeDetectorRef = _changeDetectorRef;
        this._viewContainerRef = _viewContainerRef;
        this._readyHandler = null;
        this._flagChangeHandler = null;
        this._contextChangeHandler = null;
        this._reconcilingHandler = null;
        this._updateOnContextChanged = true;
        this._updateOnConfigurationChanged = true;
        this._thenTemplateRef = templateRef;
    }
    set featureFlagDomain(domain) {
        /**
         * We have to handle the change of the domain explicitly because we need to get a new client when the domain changes.
         * This can not be done if we simply relay the onChanges method.
         */
        this._featureFlagDomain = domain;
        this.initClient();
    }
    ngOnInit() {
        this.initClient();
    }
    ngOnChanges() {
        this._flagChangeHandler?.();
    }
    ngOnDestroy() {
        if (this._client) {
            this.disposeClient(this._client);
            this._client = null;
        }
    }
    initClient() {
        if (this._client) {
            this.disposeClient(this._client);
        }
        this._client = OpenFeature.getClient(this._featureFlagDomain);
        const baseHandler = () => {
            const result = this.getFlagDetails(this._featureFlagKey, this._featureFlagDefault);
            this.onFlagValue(result, this._client.providerStatus);
        };
        this._flagChangeHandler = () => {
            if (this._updateOnConfigurationChanged) {
                baseHandler();
            }
        };
        this._contextChangeHandler = () => {
            if (this._updateOnContextChanged) {
                baseHandler();
            }
        };
        this._readyHandler = () => baseHandler();
        this._reconcilingHandler = () => baseHandler();
        this._client.addHandler(ClientProviderEvents.ConfigurationChanged, this._flagChangeHandler);
        this._client.addHandler(ClientProviderEvents.ContextChanged, this._contextChangeHandler);
        this._client.addHandler(ClientProviderEvents.Ready, this._readyHandler);
        this._client.addHandler(ClientProviderEvents.Reconciling, this._reconcilingHandler);
    }
    disposeClient(client) {
        if (this._contextChangeHandler()) {
            client.removeHandler(ClientProviderEvents.ContextChanged, this._contextChangeHandler);
        }
        if (this._flagChangeHandler) {
            client.removeHandler(ClientProviderEvents.ConfigurationChanged, this._flagChangeHandler);
        }
        if (this._readyHandler) {
            client.removeHandler(ClientProviderEvents.Ready, this._readyHandler);
        }
        if (this._reconcilingHandler) {
            client.removeHandler(ClientProviderEvents.Reconciling, this._reconcilingHandler);
        }
    }
    getFlagDetails(flagKey, defaultValue) {
        if (typeof defaultValue === 'boolean') {
            return this._client.getBooleanDetails(flagKey, defaultValue);
        }
        else if (typeof defaultValue === 'number') {
            return this._client.getNumberDetails(flagKey, defaultValue);
        }
        else if (typeof defaultValue === 'string') {
            return this._client.getStringDetails(flagKey, defaultValue);
        }
        else {
            return this._client.getObjectDetails(flagKey, defaultValue);
        }
    }
    onFlagValue(result, status) {
        const shouldInitialize = this._initializingTemplateRef && status === ClientProviderStatus.NOT_READY;
        const shouldReconcile = this._reconcilingTemplateRef && status === ClientProviderStatus.RECONCILING;
        const context = new FeatureFlagDirectiveContext(result);
        const resultChanged = !deepEqual(this._lastEvaluationResult, result);
        const isValueMatch = !this._featureFlagValue || deepEqual(result.value, this._featureFlagValue);
        if (this._initializingViewRef && shouldInitialize && !resultChanged) {
            return;
        }
        else if (this._reconcilingViewRef && shouldReconcile && !resultChanged) {
            return;
        }
        else if (this._thenViewRef && isValueMatch && !shouldInitialize && !shouldReconcile && !resultChanged) {
            return;
        }
        else if (this._elseViewRef && !isValueMatch && !shouldInitialize && !shouldReconcile && !resultChanged) {
            return;
        }
        this._lastEvaluationResult = result;
        this._viewContainerRef.clear();
        this._initializingViewRef = null;
        this._reconcilingViewRef = null;
        this._thenViewRef = null;
        this._elseViewRef = null;
        if (this._initializingTemplateRef && status === ClientProviderStatus.NOT_READY) {
            this._initializingViewRef = this._viewContainerRef.createEmbeddedView(this._initializingTemplateRef, context);
        }
        else if (this._reconcilingTemplateRef && status === ClientProviderStatus.RECONCILING) {
            this._reconcilingViewRef = this._viewContainerRef.createEmbeddedView(this._reconcilingTemplateRef, context);
        }
        else if (isValueMatch) {
            this._thenViewRef = this._viewContainerRef.createEmbeddedView(this._thenTemplateRef, context);
        }
        else if (this._elseTemplateRef) {
            this._elseViewRef = this._viewContainerRef.createEmbeddedView(this._elseTemplateRef, context);
        }
        this._changeDetectorRef.markForCheck();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: FeatureFlagDirective, deps: [{ token: i0.ChangeDetectorRef }, { token: i0.ViewContainerRef }, { token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.0", type: FeatureFlagDirective, isStandalone: true, selector: "[featureFlag]", usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: FeatureFlagDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[featureFlag]',
                }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: i0.ViewContainerRef }, { type: i0.TemplateRef }] });
/**
 * A structural directive that conditionally includes a template based on the evaluation
 * of a boolean feature flag.
 * When the flag evaluates to true, Angular renders the template provided in a `then` clause,
 * and when false, Angular renders the template provided in an optional `else` clause.
 * The default template for the `else` clause is blank.
 *
 * Usage examples:
 *
 * ```
 * <div *booleanFeatureFlag="'flagKey'; default: false; let value">{{ value }}</div>
 * ```
 * ```
 * <div *booleanFeatureFlag="flagKey; default: false; else: elseTemplate">Content to render when flag is true.</div>
 * <ng-template #elseTemplate>Content to render when flag is false.</ng-template>
 * ```
 *
 * @usageNotes
 *
 * You can specify templates for other statuses such as initializing and reconciling.
 *
 * ```
 * <div *booleanFeatureFlag="flagKey; default:true; else: elseTemplate; initializing: initializingTemplate; reconciling: reconcilingTemplate">Content to render when flag is true.</div>
 * <ng-template #elseTemplate>Content to render when flag is false.</ng-template>
 * <ng-template #initializingTemplate>Loading...</ng-template>
 * <ng-template #reconcilingTemplate>Reconfiguring...</ng-template>
 * ```
 *
 */
class BooleanFeatureFlagDirective extends FeatureFlagDirective {
    constructor(_changeDetectorRef, _viewContainerRef, templateRef) {
        super(_changeDetectorRef, _viewContainerRef, templateRef);
    }
    ngOnChanges() {
        this._featureFlagKey = this.booleanFeatureFlag;
        this._featureFlagDefault = this.booleanFeatureFlagDefault;
        this._featureFlagValue = true;
        super.ngOnChanges();
    }
    /**
     * The domain of the boolean feature flag.
     */
    set booleanFeatureFlagDomain(domain) {
        super.featureFlagDomain = domain;
    }
    /**
     * Update the component if the provider emits a ConfigurationChanged event.
     * Set to false to prevent components from re-rendering when flag value changes
     * are received by the associated provider.
     * Defaults to true.
     */
    set booleanFeatureFlagUpdateOnConfigurationChanged(enabled) {
        this._updateOnConfigurationChanged = enabled ?? true;
    }
    /**
     * Update the component when the OpenFeature context changes.
     * Set to false to prevent components from re-rendering when attributes which
     * may be factors in flag evaluation change.
     * Defaults to true.
     */
    set booleanFeatureFlagUpdateOnContextChanged(enabled) {
        this._updateOnContextChanged = enabled ?? true;
    }
    /**
     * Template to be displayed when the feature flag is false.
     */
    set booleanFeatureFlagElse(tpl) {
        this._elseTemplateRef = tpl;
    }
    /**
     * Template to be displayed when the provider is not ready.
     */
    set booleanFeatureFlagInitializing(tpl) {
        this._initializingTemplateRef = tpl;
    }
    /**
     * Template to be displayed when the provider is reconciling.
     */
    set booleanFeatureFlagReconciling(tpl) {
        this._reconcilingTemplateRef = tpl;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: BooleanFeatureFlagDirective, deps: [{ token: i0.ChangeDetectorRef }, { token: i0.ViewContainerRef }, { token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.0", type: BooleanFeatureFlagDirective, isStandalone: true, selector: "[booleanFeatureFlag]", inputs: { booleanFeatureFlag: "booleanFeatureFlag", booleanFeatureFlagDefault: "booleanFeatureFlagDefault", booleanFeatureFlagDomain: "booleanFeatureFlagDomain", booleanFeatureFlagUpdateOnConfigurationChanged: "booleanFeatureFlagUpdateOnConfigurationChanged", booleanFeatureFlagUpdateOnContextChanged: "booleanFeatureFlagUpdateOnContextChanged", booleanFeatureFlagElse: "booleanFeatureFlagElse", booleanFeatureFlagInitializing: "booleanFeatureFlagInitializing", booleanFeatureFlagReconciling: "booleanFeatureFlagReconciling" }, usesInheritance: true, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: BooleanFeatureFlagDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[booleanFeatureFlag]',
                }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: i0.ViewContainerRef }, { type: i0.TemplateRef }], propDecorators: { booleanFeatureFlag: [{
                type: Input,
                args: [{ required: true }]
            }], booleanFeatureFlagDefault: [{
                type: Input,
                args: [{ required: true }]
            }], booleanFeatureFlagDomain: [{
                type: Input,
                args: [{ required: false }]
            }], booleanFeatureFlagUpdateOnConfigurationChanged: [{
                type: Input,
                args: [{ required: false }]
            }], booleanFeatureFlagUpdateOnContextChanged: [{
                type: Input,
                args: [{ required: false }]
            }], booleanFeatureFlagElse: [{
                type: Input
            }], booleanFeatureFlagInitializing: [{
                type: Input
            }], booleanFeatureFlagReconciling: [{
                type: Input
            }] } });
/**
 * A structural directive that conditionally includes a template based on the evaluation
 * of a number feature flag.
 * When the flag matches the provided value or no expected value is given, Angular renders the template provided
 * in a `then` clause, and when it doesn't match, Angular renders the template provided
 * in an optional `else` clause.
 * The default template for the `else` clause is blank.
 *
 * Usage examples:
 *
 * ```
 * <div *numberFeatureFlag="'flagKey'; default: 0; let value">{{ value }}</div>
 * ```
 * ```
 * <div *numberFeatureFlag="'flagKey'; value: 1; default: 0; else: elseTemplate">Content to render when flag matches value.</div>
 * <ng-template #elseTemplate>Content to render when flag does not match value.</ng-template>
 * ```
 *
 * @usageNotes
 *
 * You can specify templates for other statuses such as initializing and reconciling.
 *
 * ```
 * <div *numberFeatureFlag="flagKey; default: 0; value: flagValue; else: elseTemplate; initializing: initializingTemplate; reconciling: reconcilingTemplate">Content to render when flag matches value.</div>
 * <ng-template #elseTemplate>Content to render when flag does not match value.</ng-template>
 * <ng-template #initializingTemplate>Loading...</ng-template>
 * <ng-template #reconcilingTemplate>Reconfiguring...</ng-template>
 * ```
 *
 */
class NumberFeatureFlagDirective extends FeatureFlagDirective {
    constructor(_changeDetectorRef, _viewContainerRef, templateRef) {
        super(_changeDetectorRef, _viewContainerRef, templateRef);
    }
    ngOnChanges() {
        this._featureFlagKey = this.numberFeatureFlag;
        this._featureFlagDefault = this.numberFeatureFlagDefault;
        this._featureFlagValue = this.numberFeatureFlagValue;
        super.ngOnChanges();
    }
    /**
     * The domain of the number feature flag.
     */
    set numberFeatureFlagDomain(domain) {
        super.featureFlagDomain = domain;
    }
    /**
     * Update the component if the provider emits a ConfigurationChanged event.
     * Set to false to prevent components from re-rendering when flag value changes
     * are received by the associated provider.
     * Defaults to true.
     */
    set numberFeatureFlagUpdateOnConfigurationChanged(enabled) {
        this._updateOnConfigurationChanged = enabled ?? true;
    }
    /**
     * Update the component when the OpenFeature context changes.
     * Set to false to prevent components from re-rendering when attributes which
     * may be factors in flag evaluation change.
     * Defaults to true.
     */
    set numberFeatureFlagUpdateOnContextChanged(enabled) {
        this._updateOnContextChanged = enabled ?? true;
    }
    /**
     * Template to be displayed when the feature flag does not match value.
     */
    set numberFeatureFlagElse(tpl) {
        this._elseTemplateRef = tpl;
    }
    /**
     * Template to be displayed when the feature flag is not ready.
     */
    set numberFeatureFlagInitializing(tpl) {
        this._initializingTemplateRef = tpl;
    }
    /**
     * Template to be displayed when the feature flag is not ready.
     */
    set numberFeatureFlagReconciling(tpl) {
        this._reconcilingTemplateRef = tpl;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: NumberFeatureFlagDirective, deps: [{ token: i0.ChangeDetectorRef }, { token: i0.ViewContainerRef }, { token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.0", type: NumberFeatureFlagDirective, isStandalone: true, selector: "[numberFeatureFlag]", inputs: { numberFeatureFlag: "numberFeatureFlag", numberFeatureFlagDefault: "numberFeatureFlagDefault", numberFeatureFlagValue: "numberFeatureFlagValue", numberFeatureFlagDomain: "numberFeatureFlagDomain", numberFeatureFlagUpdateOnConfigurationChanged: "numberFeatureFlagUpdateOnConfigurationChanged", numberFeatureFlagUpdateOnContextChanged: "numberFeatureFlagUpdateOnContextChanged", numberFeatureFlagElse: "numberFeatureFlagElse", numberFeatureFlagInitializing: "numberFeatureFlagInitializing", numberFeatureFlagReconciling: "numberFeatureFlagReconciling" }, usesInheritance: true, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: NumberFeatureFlagDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[numberFeatureFlag]',
                }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: i0.ViewContainerRef }, { type: i0.TemplateRef }], propDecorators: { numberFeatureFlag: [{
                type: Input,
                args: [{ required: true }]
            }], numberFeatureFlagDefault: [{
                type: Input,
                args: [{ required: true }]
            }], numberFeatureFlagValue: [{
                type: Input,
                args: [{ required: false }]
            }], numberFeatureFlagDomain: [{
                type: Input,
                args: [{ required: false }]
            }], numberFeatureFlagUpdateOnConfigurationChanged: [{
                type: Input,
                args: [{ required: false }]
            }], numberFeatureFlagUpdateOnContextChanged: [{
                type: Input,
                args: [{ required: false }]
            }], numberFeatureFlagElse: [{
                type: Input
            }], numberFeatureFlagInitializing: [{
                type: Input
            }], numberFeatureFlagReconciling: [{
                type: Input
            }] } });
/**
 * A structural directive that conditionally includes a template based on the evaluation
 * of a string feature flag.
 * When the flag matches the provided value or no expected value is given, Angular renders the template provided
 * in a `then` clause, and when it doesn't match, Angular renders the template provided
 * in an optional `else` clause.
 * The default template for the `else` clause is blank.
 *
 * Usage examples:
 *
 * ```
 * <div *stringFeatureFlag="'flagKey'; default: 'default'; let value">{{ value }}</div>
 * ```
 * ```
 * <div *stringFeatureFlag="flagKey; default: 'default'; value: flagValue; else: elseTemplate">Content to render when flag matches value.</div>
 * <ng-template #elseTemplate>Content to render when flag does not match value.</ng-template>
 * ```
 *
 * @usageNotes
 *
 * You can specify templates for other statuses such as initializing and reconciling.
 *
 * ```
 * <div *stringFeatureFlag="flagKey; default: 'default'; value: flagValue; else: elseTemplate; initializing: initializingTemplate; reconciling: reconcilingTemplate">Content to render when flag matches value.</div>
 * <ng-template #elseTemplate>Content to render when flag does not match value.</ng-template>
 * <ng-template #initializingTemplate>Loading...</ng-template>
 * <ng-template #reconcilingTemplate>Reconfiguring...</ng-template>
 * ```
 *
 */
class StringFeatureFlagDirective extends FeatureFlagDirective {
    constructor(_changeDetectorRef, _viewContainerRef, templateRef) {
        super(_changeDetectorRef, _viewContainerRef, templateRef);
    }
    ngOnChanges() {
        this._featureFlagKey = this.stringFeatureFlag;
        this._featureFlagDefault = this.stringFeatureFlagDefault;
        this._featureFlagValue = this.stringFeatureFlagValue;
        super.ngOnChanges();
    }
    /**
     * The domain for the string feature flag.
     */
    set stringFeatureFlagDomain(domain) {
        super.featureFlagDomain = domain;
    }
    /**
     * Update the component if the provider emits a ConfigurationChanged event.
     * Set to false to prevent components from re-rendering when flag value changes
     * are received by the associated provider.
     * Defaults to true.
     */
    set stringFeatureFlagUpdateOnConfigurationChanged(enabled) {
        this._updateOnConfigurationChanged = enabled ?? true;
    }
    /**
     * Update the component when the OpenFeature context changes.
     * Set to false to prevent components from re-rendering when attributes which
     * may be factors in flag evaluation change.
     * Defaults to true.
     */
    set stringFeatureFlagUpdateOnContextChanged(enabled) {
        this._updateOnContextChanged = enabled ?? true;
    }
    /**
     * Template to be displayed when the feature flag does not match value.
     */
    set stringFeatureFlagElse(tpl) {
        this._elseTemplateRef = tpl;
    }
    /**
     * Template to be displayed when the feature flag is not ready.
     */
    set stringFeatureFlagInitializing(tpl) {
        this._initializingTemplateRef = tpl;
    }
    /**
     * Template to be displayed when the feature flag is reconciling.
     */
    set stringFeatureFlagReconciling(tpl) {
        this._reconcilingTemplateRef = tpl;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: StringFeatureFlagDirective, deps: [{ token: i0.ChangeDetectorRef }, { token: i0.ViewContainerRef }, { token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.0", type: StringFeatureFlagDirective, isStandalone: true, selector: "[stringFeatureFlag]", inputs: { stringFeatureFlag: "stringFeatureFlag", stringFeatureFlagDefault: "stringFeatureFlagDefault", stringFeatureFlagValue: "stringFeatureFlagValue", stringFeatureFlagDomain: "stringFeatureFlagDomain", stringFeatureFlagUpdateOnConfigurationChanged: "stringFeatureFlagUpdateOnConfigurationChanged", stringFeatureFlagUpdateOnContextChanged: "stringFeatureFlagUpdateOnContextChanged", stringFeatureFlagElse: "stringFeatureFlagElse", stringFeatureFlagInitializing: "stringFeatureFlagInitializing", stringFeatureFlagReconciling: "stringFeatureFlagReconciling" }, usesInheritance: true, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: StringFeatureFlagDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[stringFeatureFlag]',
                }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: i0.ViewContainerRef }, { type: i0.TemplateRef }], propDecorators: { stringFeatureFlag: [{
                type: Input,
                args: [{ required: true }]
            }], stringFeatureFlagDefault: [{
                type: Input,
                args: [{ required: true }]
            }], stringFeatureFlagValue: [{
                type: Input,
                args: [{ required: false }]
            }], stringFeatureFlagDomain: [{
                type: Input,
                args: [{ required: false }]
            }], stringFeatureFlagUpdateOnConfigurationChanged: [{
                type: Input,
                args: [{ required: false }]
            }], stringFeatureFlagUpdateOnContextChanged: [{
                type: Input,
                args: [{ required: false }]
            }], stringFeatureFlagElse: [{
                type: Input
            }], stringFeatureFlagInitializing: [{
                type: Input
            }], stringFeatureFlagReconciling: [{
                type: Input
            }] } });
/**
 * A structural directive that conditionally includes a template based on the evaluation
 * of an object feature flag.
 * When the flag matches the provided value or no expected value is given, Angular renders the template provided
 * in a `then` clause, and when it doesn't match, Angular renders the template provided
 * in an optional `else` clause.
 * The default template for the `else` clause is blank.
 *
 * Usage examples:
 *
 * ```
 * <div *objectFeatureFlag="'flagKey'; default: {}; let value">{{ value }}</div>
 * ```
 * ```
 * <div *objectFeatureFlag="flagKey; default: {}; value: flagValue; else: elseTemplate">Content to render when flag matches value.</div>
 * <ng-template #elseTemplate>Content to render when flag does not match value.</ng-template>
 * ```
 *
 * @usageNotes
 *
 * You can specify templates for other statuses such as initializing and reconciling.
 *
 * ```
 * <div *objectFeatureFlag="flagKey; default: {}; value: flagValue; else: elseTemplate; initializing: initializingTemplate; reconciling: reconcilingTemplate">Content to render when flag matches value.</div>
 * <ng-template #elseTemplate>Content to render when flag does not match value.</ng-template>
 * <ng-template #initializingTemplate>Loading...</ng-template>
 * <ng-template #reconcilingTemplate>Reconfiguring...</ng-template>
 * ```
 *
 */
class ObjectFeatureFlagDirective extends FeatureFlagDirective {
    constructor(_changeDetectorRef, _viewContainerRef, templateRef) {
        super(_changeDetectorRef, _viewContainerRef, templateRef);
    }
    ngOnChanges() {
        this._featureFlagKey = this.objectFeatureFlag;
        this._featureFlagDefault = this.objectFeatureFlagDefault;
        this._featureFlagValue = this.objectFeatureFlagValue;
        super.ngOnChanges();
    }
    /**
     * The domain for the object feature flag.
     */
    set objectFeatureFlagDomain(domain) {
        super.featureFlagDomain = domain;
    }
    /**
     * Update the component if the provider emits a ConfigurationChanged event.
     * Set to false to prevent components from re-rendering when flag value changes
     * are received by the associated provider.
     * Defaults to true.
     */
    set objectFeatureFlagUpdateOnConfigurationChanged(enabled) {
        this._updateOnConfigurationChanged = enabled ?? true;
    }
    /**
     * Update the component when the OpenFeature context changes.
     * Set to false to prevent components from re-rendering when attributes which
     * may be factors in flag evaluation change.
     * Defaults to true.
     */
    set objectFeatureFlagUpdateOnContextChanged(enabled) {
        this._updateOnContextChanged = enabled ?? true;
    }
    /**
     * Template to be displayed when the feature flag does not match value.
     */
    set objectFeatureFlagElse(tpl) {
        this._elseTemplateRef = tpl;
    }
    /**
     * Template to be displayed when the feature flag is not ready.
     */
    set objectFeatureFlagInitializing(tpl) {
        this._initializingTemplateRef = tpl;
    }
    /**
     * Template to be displayed when the feature flag is reconciling.
     */
    set objectFeatureFlagReconciling(tpl) {
        this._reconcilingTemplateRef = tpl;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: ObjectFeatureFlagDirective, deps: [{ token: i0.ChangeDetectorRef }, { token: i0.ViewContainerRef }, { token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.0", type: ObjectFeatureFlagDirective, isStandalone: true, selector: "[objectFeatureFlag]", inputs: { objectFeatureFlag: "objectFeatureFlag", objectFeatureFlagDefault: "objectFeatureFlagDefault", objectFeatureFlagValue: "objectFeatureFlagValue", objectFeatureFlagDomain: "objectFeatureFlagDomain", objectFeatureFlagUpdateOnConfigurationChanged: "objectFeatureFlagUpdateOnConfigurationChanged", objectFeatureFlagUpdateOnContextChanged: "objectFeatureFlagUpdateOnContextChanged", objectFeatureFlagElse: "objectFeatureFlagElse", objectFeatureFlagInitializing: "objectFeatureFlagInitializing", objectFeatureFlagReconciling: "objectFeatureFlagReconciling" }, usesInheritance: true, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: ObjectFeatureFlagDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[objectFeatureFlag]',
                }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: i0.ViewContainerRef }, { type: i0.TemplateRef }], propDecorators: { objectFeatureFlag: [{
                type: Input,
                args: [{ required: true }]
            }], objectFeatureFlagDefault: [{
                type: Input,
                args: [{ required: true }]
            }], objectFeatureFlagValue: [{
                type: Input,
                args: [{ required: false }]
            }], objectFeatureFlagDomain: [{
                type: Input,
                args: [{ required: false }]
            }], objectFeatureFlagUpdateOnConfigurationChanged: [{
                type: Input,
                args: [{ required: false }]
            }], objectFeatureFlagUpdateOnContextChanged: [{
                type: Input,
                args: [{ required: false }]
            }], objectFeatureFlagElse: [{
                type: Input
            }], objectFeatureFlagInitializing: [{
                type: Input
            }], objectFeatureFlagReconciling: [{
                type: Input
            }] } });
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function deepEqual(obj1, obj2) {
    if (obj1 === obj2) {
        // If both objects are identical
        return true;
    }
    if (typeof obj1 !== 'object' || obj1 === null || typeof obj2 !== 'object' || obj2 === null) {
        // One of them is not an object or one of them is null
        return false;
    }
    const keys1 = Object.keys(obj1);
    const keys2 = Object.keys(obj2);
    if (keys1.length !== keys2.length) {
        // Different number of properties
        return false;
    }
    for (const key of keys1) {
        if (!keys2.includes(key)) {
            // obj2 does not have a property that obj1 has
            return false;
        }
        // Recursive check for each property
        if (!deepEqual(obj1[key], obj2[key])) {
            return false;
        }
    }
    return true;
}

const OPEN_FEATURE_CONFIG_TOKEN = new InjectionToken('OPEN_FEATURE_CONFIG_TOKEN');
class OpenFeatureModule {
    static forRoot(config) {
        const context = typeof config.context === 'function' ? config.context() : config.context;
        OpenFeature.setProvider(config.provider, context);
        if (config.domainBoundProviders) {
            Object.entries(config.domainBoundProviders).map(([domain, provider]) => OpenFeature.setProvider(domain, provider));
        }
        return {
            ngModule: OpenFeatureModule,
            providers: [{ provide: OPEN_FEATURE_CONFIG_TOKEN, useValue: config }],
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: OpenFeatureModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.0", ngImport: i0, type: OpenFeatureModule, imports: [CommonModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: OpenFeatureModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: OpenFeatureModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [CommonModule],
                    exports: [],
                }]
        }] });

/*
 * Public API Surface of angular
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BooleanFeatureFlagDirective, FeatureFlagDirective, NumberFeatureFlagDirective, OPEN_FEATURE_CONFIG_TOKEN, ObjectFeatureFlagDirective, OpenFeatureModule, StringFeatureFlagDirective };
//# sourceMappingURL=openfeature-angular-sdk.mjs.map
