import { ChangeDetectorRef, EmbeddedViewRef, OnChanges, OnDestroy, OnInit, TemplateRef, ViewContainerRef } from '@angular/core';
import { Client, ClientProviderEvents, ClientProviderStatus, EvaluationDetails, EventHandler, FlagValue, JsonValue } from '@openfeature/web-sdk';
import * as i0 from "@angular/core";
declare class FeatureFlagDirectiveContext<T extends FlagValue> {
    $implicit: T;
    evaluationDetails: EvaluationDetails<T>;
    constructor(details: EvaluationDetails<T>);
}
export declare abstract class FeatureFlagDirective<T extends FlagValue> implements OnInit, OnDestroy, OnChanges {
    protected _changeDetectorRef: ChangeDetectorRef;
    protected _viewContainerRef: ViewContainerRef;
    protected _featureFlagDefault: T;
    protected _featureFlagDomain: string | undefined;
    protected _featureFlagKey: string;
    protected _featureFlagValue?: T;
    protected _client: Client;
    protected _lastEvaluationResult: EvaluationDetails<T>;
    protected _readyHandler: EventHandler<ClientProviderEvents.Ready> | null;
    protected _flagChangeHandler: EventHandler<ClientProviderEvents.ConfigurationChanged> | null;
    protected _contextChangeHandler: EventHandler<ClientProviderEvents.Error> | null;
    protected _reconcilingHandler: EventHandler<ClientProviderEvents.Reconciling> | null;
    protected _updateOnContextChanged: boolean;
    protected _updateOnConfigurationChanged: boolean;
    protected _thenTemplateRef: TemplateRef<FeatureFlagDirectiveContext<T>> | null;
    protected _thenViewRef: EmbeddedViewRef<unknown> | null;
    protected _elseTemplateRef: TemplateRef<FeatureFlagDirectiveContext<T>> | null;
    protected _elseViewRef: EmbeddedViewRef<unknown> | null;
    protected _initializingTemplateRef: TemplateRef<FeatureFlagDirectiveContext<T>> | null;
    protected _initializingViewRef: EmbeddedViewRef<unknown> | null;
    protected _reconcilingTemplateRef: TemplateRef<FeatureFlagDirectiveContext<T>> | null;
    protected _reconcilingViewRef: EmbeddedViewRef<unknown> | null;
    protected constructor(_changeDetectorRef: ChangeDetectorRef, _viewContainerRef: ViewContainerRef, templateRef: TemplateRef<FeatureFlagDirectiveContext<T>>);
    set featureFlagDomain(domain: string | undefined);
    ngOnInit(): void;
    ngOnChanges(): void;
    ngOnDestroy(): void;
    private initClient;
    private disposeClient;
    protected getFlagDetails(flagKey: string, defaultValue: T): EvaluationDetails<T>;
    protected onFlagValue(result: EvaluationDetails<T>, status: ClientProviderStatus): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FeatureFlagDirective<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FeatureFlagDirective<any>, "[featureFlag]", never, {}, {}, never, never, true, never>;
}
/**
 * A structural directive that conditionally includes a template based on the evaluation
 * of a boolean feature flag.
 * When the flag evaluates to true, Angular renders the template provided in a `then` clause,
 * and when false, Angular renders the template provided in an optional `else` clause.
 * The default template for the `else` clause is blank.
 *
 * Usage examples:
 *
 * ```
 * <div *booleanFeatureFlag="'flagKey'; default: false; let value">{{ value }}</div>
 * ```
 * ```
 * <div *booleanFeatureFlag="flagKey; default: false; else: elseTemplate">Content to render when flag is true.</div>
 * <ng-template #elseTemplate>Content to render when flag is false.</ng-template>
 * ```
 *
 * @usageNotes
 *
 * You can specify templates for other statuses such as initializing and reconciling.
 *
 * ```
 * <div *booleanFeatureFlag="flagKey; default:true; else: elseTemplate; initializing: initializingTemplate; reconciling: reconcilingTemplate">Content to render when flag is true.</div>
 * <ng-template #elseTemplate>Content to render when flag is false.</ng-template>
 * <ng-template #initializingTemplate>Loading...</ng-template>
 * <ng-template #reconcilingTemplate>Reconfiguring...</ng-template>
 * ```
 *
 */
export declare class BooleanFeatureFlagDirective extends FeatureFlagDirective<boolean> implements OnChanges {
    /**
     * The key of the boolean feature flag.
     */
    booleanFeatureFlag: string;
    /**
     * The default value for the boolean feature flag.
     */
    booleanFeatureFlagDefault: boolean;
    constructor(_changeDetectorRef: ChangeDetectorRef, _viewContainerRef: ViewContainerRef, templateRef: TemplateRef<FeatureFlagDirectiveContext<boolean>>);
    ngOnChanges(): void;
    /**
     * The domain of the boolean feature flag.
     */
    set booleanFeatureFlagDomain(domain: string | undefined);
    /**
     * Update the component if the provider emits a ConfigurationChanged event.
     * Set to false to prevent components from re-rendering when flag value changes
     * are received by the associated provider.
     * Defaults to true.
     */
    set booleanFeatureFlagUpdateOnConfigurationChanged(enabled: boolean | undefined);
    /**
     * Update the component when the OpenFeature context changes.
     * Set to false to prevent components from re-rendering when attributes which
     * may be factors in flag evaluation change.
     * Defaults to true.
     */
    set booleanFeatureFlagUpdateOnContextChanged(enabled: boolean | undefined);
    /**
     * Template to be displayed when the feature flag is false.
     */
    set booleanFeatureFlagElse(tpl: TemplateRef<FeatureFlagDirectiveContext<boolean>>);
    /**
     * Template to be displayed when the provider is not ready.
     */
    set booleanFeatureFlagInitializing(tpl: TemplateRef<FeatureFlagDirectiveContext<boolean>>);
    /**
     * Template to be displayed when the provider is reconciling.
     */
    set booleanFeatureFlagReconciling(tpl: TemplateRef<FeatureFlagDirectiveContext<boolean>>);
    static ɵfac: i0.ɵɵFactoryDeclaration<BooleanFeatureFlagDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BooleanFeatureFlagDirective, "[booleanFeatureFlag]", never, { "booleanFeatureFlag": { "alias": "booleanFeatureFlag"; "required": true; }; "booleanFeatureFlagDefault": { "alias": "booleanFeatureFlagDefault"; "required": true; }; "booleanFeatureFlagDomain": { "alias": "booleanFeatureFlagDomain"; "required": false; }; "booleanFeatureFlagUpdateOnConfigurationChanged": { "alias": "booleanFeatureFlagUpdateOnConfigurationChanged"; "required": false; }; "booleanFeatureFlagUpdateOnContextChanged": { "alias": "booleanFeatureFlagUpdateOnContextChanged"; "required": false; }; "booleanFeatureFlagElse": { "alias": "booleanFeatureFlagElse"; "required": false; }; "booleanFeatureFlagInitializing": { "alias": "booleanFeatureFlagInitializing"; "required": false; }; "booleanFeatureFlagReconciling": { "alias": "booleanFeatureFlagReconciling"; "required": false; }; }, {}, never, never, true, never>;
}
/**
 * A structural directive that conditionally includes a template based on the evaluation
 * of a number feature flag.
 * When the flag matches the provided value or no expected value is given, Angular renders the template provided
 * in a `then` clause, and when it doesn't match, Angular renders the template provided
 * in an optional `else` clause.
 * The default template for the `else` clause is blank.
 *
 * Usage examples:
 *
 * ```
 * <div *numberFeatureFlag="'flagKey'; default: 0; let value">{{ value }}</div>
 * ```
 * ```
 * <div *numberFeatureFlag="'flagKey'; value: 1; default: 0; else: elseTemplate">Content to render when flag matches value.</div>
 * <ng-template #elseTemplate>Content to render when flag does not match value.</ng-template>
 * ```
 *
 * @usageNotes
 *
 * You can specify templates for other statuses such as initializing and reconciling.
 *
 * ```
 * <div *numberFeatureFlag="flagKey; default: 0; value: flagValue; else: elseTemplate; initializing: initializingTemplate; reconciling: reconcilingTemplate">Content to render when flag matches value.</div>
 * <ng-template #elseTemplate>Content to render when flag does not match value.</ng-template>
 * <ng-template #initializingTemplate>Loading...</ng-template>
 * <ng-template #reconcilingTemplate>Reconfiguring...</ng-template>
 * ```
 *
 */
export declare class NumberFeatureFlagDirective extends FeatureFlagDirective<number> implements OnChanges {
    /**
     * The key of the number feature flag.
     */
    numberFeatureFlag: string;
    /**
     * The default value for the number feature flag.
     */
    numberFeatureFlagDefault: number;
    /**
     * The expected value of this number feature flag, for which the `then` template should be rendered.
     */
    numberFeatureFlagValue?: number;
    constructor(_changeDetectorRef: ChangeDetectorRef, _viewContainerRef: ViewContainerRef, templateRef: TemplateRef<FeatureFlagDirectiveContext<number>>);
    ngOnChanges(): void;
    /**
     * The domain of the number feature flag.
     */
    set numberFeatureFlagDomain(domain: string | undefined);
    /**
     * Update the component if the provider emits a ConfigurationChanged event.
     * Set to false to prevent components from re-rendering when flag value changes
     * are received by the associated provider.
     * Defaults to true.
     */
    set numberFeatureFlagUpdateOnConfigurationChanged(enabled: boolean | undefined);
    /**
     * Update the component when the OpenFeature context changes.
     * Set to false to prevent components from re-rendering when attributes which
     * may be factors in flag evaluation change.
     * Defaults to true.
     */
    set numberFeatureFlagUpdateOnContextChanged(enabled: boolean | undefined);
    /**
     * Template to be displayed when the feature flag does not match value.
     */
    set numberFeatureFlagElse(tpl: TemplateRef<FeatureFlagDirectiveContext<number>>);
    /**
     * Template to be displayed when the feature flag is not ready.
     */
    set numberFeatureFlagInitializing(tpl: TemplateRef<FeatureFlagDirectiveContext<number>>);
    /**
     * Template to be displayed when the feature flag is not ready.
     */
    set numberFeatureFlagReconciling(tpl: TemplateRef<FeatureFlagDirectiveContext<number>>);
    static ɵfac: i0.ɵɵFactoryDeclaration<NumberFeatureFlagDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NumberFeatureFlagDirective, "[numberFeatureFlag]", never, { "numberFeatureFlag": { "alias": "numberFeatureFlag"; "required": true; }; "numberFeatureFlagDefault": { "alias": "numberFeatureFlagDefault"; "required": true; }; "numberFeatureFlagValue": { "alias": "numberFeatureFlagValue"; "required": false; }; "numberFeatureFlagDomain": { "alias": "numberFeatureFlagDomain"; "required": false; }; "numberFeatureFlagUpdateOnConfigurationChanged": { "alias": "numberFeatureFlagUpdateOnConfigurationChanged"; "required": false; }; "numberFeatureFlagUpdateOnContextChanged": { "alias": "numberFeatureFlagUpdateOnContextChanged"; "required": false; }; "numberFeatureFlagElse": { "alias": "numberFeatureFlagElse"; "required": false; }; "numberFeatureFlagInitializing": { "alias": "numberFeatureFlagInitializing"; "required": false; }; "numberFeatureFlagReconciling": { "alias": "numberFeatureFlagReconciling"; "required": false; }; }, {}, never, never, true, never>;
}
/**
 * A structural directive that conditionally includes a template based on the evaluation
 * of a string feature flag.
 * When the flag matches the provided value or no expected value is given, Angular renders the template provided
 * in a `then` clause, and when it doesn't match, Angular renders the template provided
 * in an optional `else` clause.
 * The default template for the `else` clause is blank.
 *
 * Usage examples:
 *
 * ```
 * <div *stringFeatureFlag="'flagKey'; default: 'default'; let value">{{ value }}</div>
 * ```
 * ```
 * <div *stringFeatureFlag="flagKey; default: 'default'; value: flagValue; else: elseTemplate">Content to render when flag matches value.</div>
 * <ng-template #elseTemplate>Content to render when flag does not match value.</ng-template>
 * ```
 *
 * @usageNotes
 *
 * You can specify templates for other statuses such as initializing and reconciling.
 *
 * ```
 * <div *stringFeatureFlag="flagKey; default: 'default'; value: flagValue; else: elseTemplate; initializing: initializingTemplate; reconciling: reconcilingTemplate">Content to render when flag matches value.</div>
 * <ng-template #elseTemplate>Content to render when flag does not match value.</ng-template>
 * <ng-template #initializingTemplate>Loading...</ng-template>
 * <ng-template #reconcilingTemplate>Reconfiguring...</ng-template>
 * ```
 *
 */
export declare class StringFeatureFlagDirective extends FeatureFlagDirective<string> implements OnChanges {
    /**
     * The key of the string feature flag.
     */
    stringFeatureFlag: string;
    /**
     * The default value for the string feature flag.
     */
    stringFeatureFlagDefault: string;
    /**
     * The expected value of this string feature flag, for which the `then` template should be rendered.
     */
    stringFeatureFlagValue?: string;
    constructor(_changeDetectorRef: ChangeDetectorRef, _viewContainerRef: ViewContainerRef, templateRef: TemplateRef<FeatureFlagDirectiveContext<string>>);
    ngOnChanges(): void;
    /**
     * The domain for the string feature flag.
     */
    set stringFeatureFlagDomain(domain: string | undefined);
    /**
     * Update the component if the provider emits a ConfigurationChanged event.
     * Set to false to prevent components from re-rendering when flag value changes
     * are received by the associated provider.
     * Defaults to true.
     */
    set stringFeatureFlagUpdateOnConfigurationChanged(enabled: boolean | undefined);
    /**
     * Update the component when the OpenFeature context changes.
     * Set to false to prevent components from re-rendering when attributes which
     * may be factors in flag evaluation change.
     * Defaults to true.
     */
    set stringFeatureFlagUpdateOnContextChanged(enabled: boolean | undefined);
    /**
     * Template to be displayed when the feature flag does not match value.
     */
    set stringFeatureFlagElse(tpl: TemplateRef<FeatureFlagDirectiveContext<string>>);
    /**
     * Template to be displayed when the feature flag is not ready.
     */
    set stringFeatureFlagInitializing(tpl: TemplateRef<FeatureFlagDirectiveContext<string>>);
    /**
     * Template to be displayed when the feature flag is reconciling.
     */
    set stringFeatureFlagReconciling(tpl: TemplateRef<FeatureFlagDirectiveContext<string>>);
    static ɵfac: i0.ɵɵFactoryDeclaration<StringFeatureFlagDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<StringFeatureFlagDirective, "[stringFeatureFlag]", never, { "stringFeatureFlag": { "alias": "stringFeatureFlag"; "required": true; }; "stringFeatureFlagDefault": { "alias": "stringFeatureFlagDefault"; "required": true; }; "stringFeatureFlagValue": { "alias": "stringFeatureFlagValue"; "required": false; }; "stringFeatureFlagDomain": { "alias": "stringFeatureFlagDomain"; "required": false; }; "stringFeatureFlagUpdateOnConfigurationChanged": { "alias": "stringFeatureFlagUpdateOnConfigurationChanged"; "required": false; }; "stringFeatureFlagUpdateOnContextChanged": { "alias": "stringFeatureFlagUpdateOnContextChanged"; "required": false; }; "stringFeatureFlagElse": { "alias": "stringFeatureFlagElse"; "required": false; }; "stringFeatureFlagInitializing": { "alias": "stringFeatureFlagInitializing"; "required": false; }; "stringFeatureFlagReconciling": { "alias": "stringFeatureFlagReconciling"; "required": false; }; }, {}, never, never, true, never>;
}
/**
 * A structural directive that conditionally includes a template based on the evaluation
 * of an object feature flag.
 * When the flag matches the provided value or no expected value is given, Angular renders the template provided
 * in a `then` clause, and when it doesn't match, Angular renders the template provided
 * in an optional `else` clause.
 * The default template for the `else` clause is blank.
 *
 * Usage examples:
 *
 * ```
 * <div *objectFeatureFlag="'flagKey'; default: {}; let value">{{ value }}</div>
 * ```
 * ```
 * <div *objectFeatureFlag="flagKey; default: {}; value: flagValue; else: elseTemplate">Content to render when flag matches value.</div>
 * <ng-template #elseTemplate>Content to render when flag does not match value.</ng-template>
 * ```
 *
 * @usageNotes
 *
 * You can specify templates for other statuses such as initializing and reconciling.
 *
 * ```
 * <div *objectFeatureFlag="flagKey; default: {}; value: flagValue; else: elseTemplate; initializing: initializingTemplate; reconciling: reconcilingTemplate">Content to render when flag matches value.</div>
 * <ng-template #elseTemplate>Content to render when flag does not match value.</ng-template>
 * <ng-template #initializingTemplate>Loading...</ng-template>
 * <ng-template #reconcilingTemplate>Reconfiguring...</ng-template>
 * ```
 *
 */
export declare class ObjectFeatureFlagDirective<T extends JsonValue> extends FeatureFlagDirective<T> implements OnChanges {
    /**
     * The key of the object feature flag.
     */
    objectFeatureFlag: string;
    /**
     * The default value for the object feature flag.
     */
    objectFeatureFlagDefault: T;
    /**
     * The expected value of this object feature flag, for which the `then` template should be rendered.
     */
    objectFeatureFlagValue?: T;
    constructor(_changeDetectorRef: ChangeDetectorRef, _viewContainerRef: ViewContainerRef, templateRef: TemplateRef<FeatureFlagDirectiveContext<T>>);
    ngOnChanges(): void;
    /**
     * The domain for the object feature flag.
     */
    set objectFeatureFlagDomain(domain: string | undefined);
    /**
     * Update the component if the provider emits a ConfigurationChanged event.
     * Set to false to prevent components from re-rendering when flag value changes
     * are received by the associated provider.
     * Defaults to true.
     */
    set objectFeatureFlagUpdateOnConfigurationChanged(enabled: boolean | undefined);
    /**
     * Update the component when the OpenFeature context changes.
     * Set to false to prevent components from re-rendering when attributes which
     * may be factors in flag evaluation change.
     * Defaults to true.
     */
    set objectFeatureFlagUpdateOnContextChanged(enabled: boolean | undefined);
    /**
     * Template to be displayed when the feature flag does not match value.
     */
    set objectFeatureFlagElse(tpl: TemplateRef<FeatureFlagDirectiveContext<T>>);
    /**
     * Template to be displayed when the feature flag is not ready.
     */
    set objectFeatureFlagInitializing(tpl: TemplateRef<FeatureFlagDirectiveContext<T>>);
    /**
     * Template to be displayed when the feature flag is reconciling.
     */
    set objectFeatureFlagReconciling(tpl: TemplateRef<FeatureFlagDirectiveContext<T>>);
    static ɵfac: i0.ɵɵFactoryDeclaration<ObjectFeatureFlagDirective<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ObjectFeatureFlagDirective<any>, "[objectFeatureFlag]", never, { "objectFeatureFlag": { "alias": "objectFeatureFlag"; "required": true; }; "objectFeatureFlagDefault": { "alias": "objectFeatureFlagDefault"; "required": true; }; "objectFeatureFlagValue": { "alias": "objectFeatureFlagValue"; "required": false; }; "objectFeatureFlagDomain": { "alias": "objectFeatureFlagDomain"; "required": false; }; "objectFeatureFlagUpdateOnConfigurationChanged": { "alias": "objectFeatureFlagUpdateOnConfigurationChanged"; "required": false; }; "objectFeatureFlagUpdateOnContextChanged": { "alias": "objectFeatureFlagUpdateOnContextChanged"; "required": false; }; "objectFeatureFlagElse": { "alias": "objectFeatureFlagElse"; "required": false; }; "objectFeatureFlagInitializing": { "alias": "objectFeatureFlagInitializing"; "required": false; }; "objectFeatureFlagReconciling": { "alias": "objectFeatureFlagReconciling"; "required": false; }; }, {}, never, never, true, never>;
}
export {};
